@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-""" PyCorrFit - Module frontend
+u""" PyCorrFit - Module frontend
 
 The frontend displays the GUI (Graphic User Interface). All necessary 
 functions and modules are called from here.
@@ -39,6 +39,7 @@ import numpy as np                      # NumPy
 import platform
 import sys                              # System stuff
 import traceback                        # for Error handling
+import warnings
 
 try:
     # contains e.g. update and icon, but no vital things.
@@ -48,16 +49,20 @@ except ImportError:
     print " Update function will not work."
 
 # PyCorrFit modules
-import doc                          # Documentation/some texts
-import edclasses
+from . import doc                          # Documentation/some texts
+from . import edclasses
 
-import models as mdls
-import openfile as opf              # How to treat an opened file
-import page
-import plotting
-import readfiles
-import tools                        # Some tools
-import usermodel
+from . import models as mdls
+from . import openfile as opf              # How to treat an opened file
+from . import page
+try:
+    from . import plotting
+except ImportError:
+    warnings.warn("Submodule `pycorrfit.plotting` will not be "+\
+             "available. Reason: {}.".format(sys.exc_info()[1].message))
+from . import readfiles
+from . import tools                        # Some tools
+from . import usermodel
 
 
 ## On Windows XP I had problems with the unicode Characters.
@@ -70,7 +75,16 @@ if platform.system() == 'Windows':
 # ~paulmueller
 
 
-###########################################################
+########################################################################
+class ExceptionDialog(wx.MessageDialog):
+    """"""
+    def __init__(self, msg):
+        """Constructor"""
+        wx.MessageDialog.__init__(self, None, msg, "Error",
+                                          wx.OK|wx.ICON_ERROR)   
+
+
+########################################################################
 class FlatNotebookDemo(fnb.FlatNotebook):
     """
     Flatnotebook class
@@ -105,6 +119,8 @@ class MyApp(wx.App):
 ###########################################################
 class MyFrame(wx.Frame):
     def __init__(self, parent, id, version):
+
+        sys.excepthook = MyExceptionHook
         ## Set initial variables that make sense
         tau = 10**np.linspace(-6,8,1001)
 
@@ -454,12 +470,12 @@ class MyFrame(wx.Frame):
         info.SetName('PyCorrFit')
         info.SetVersion(self.version)
         info.SetDescription(description)
-        info.SetCopyright('(C) 2011 - 2012 Paul Müller')
+        info.SetCopyright(u'(C) 2011 - 2012 Paul Müller')
         info.SetWebSite(doc.HomePage)
         info.SetLicence(licence)
         info.SetIcon(misc.getMainIcon(pxlength=64))
-        info.AddDeveloper('Paul Müller')
-        info.AddDocWriter('Thomas Weidemann, Paul Müller')
+        info.AddDeveloper(u'Paul Müller')
+        info.AddDocWriter(u'Thomas Weidemann, Paul Müller')
         wx.AboutBox(info)
         
 
@@ -704,7 +720,7 @@ class MyFrame(wx.Frame):
         # Get the Page
         if Page is None:
             Page = self.notebook.GetCurrentPage()
-        keys = self.ToolsOpen.keys()
+        keys = list(self.ToolsOpen.keys())
         for key in keys:
             # Update the information
             self.ToolsOpen[key].OnPageChanged(Page, trigger=trigger)
@@ -1044,7 +1060,7 @@ class MyFrame(wx.Frame):
         for j in np.arange(N):
             afile=Datafiles[j]
             # Let the user abort, if he wants to:
-            if dlgi.Update(i+1, "Loading data: "+afile)[0] == False:
+            if dlgi.Update(j+1, "Loading data: "+afile)[0] == False:
                 dlgi.Destroy()
                 return
             #Stuff = readfiles.openAny(self.dirname, afile)
@@ -1551,7 +1567,8 @@ class MyFrame(wx.Frame):
             self.dirname = dlg.GetDirectory()
             self.filename = None
             # Set title of our window
-        if not self.filename.endswith(".pcfs"):
+        if (self.filename is not None and
+            not self.filename.endswith(".pcfs")):
             self.filename += ".pcfs"
         dlg.Destroy()
         self.SetTitleFCS(self.filename)
@@ -1769,3 +1786,23 @@ class MyFrame(wx.Frame):
             self.SetTitle('PyCorrFit ' + self.version + title)
         else:
             self.SetTitle('PyCorrFit ' + self.version)
+
+
+def MyExceptionHook(etype, value, trace):
+    """
+    Handler for all unhandled exceptions.
+ 
+    :param `etype`: the exception type (`SyntaxError`, `ZeroDivisionError`, etc...);
+    :type `etype`: `Exception`
+    :param string `value`: the exception error message;
+    :param string `trace`: the traceback header, if any (otherwise, it prints the
+     standard Python header: ``Traceback (most recent call last)``.
+    """
+    frame = wx.GetApp().GetTopWindow()
+    tmp = traceback.format_exception(etype, value, trace)
+    exception = "".join(tmp)
+ 
+    dlg = ExceptionDialog(exception)
+    dlg.ShowModal()
+    dlg.Destroy()     
+    wx.EndBusyCursor()
